pub struct HelpConfiguration<'a> {
pub extra_text_at_bottom: &'a str,
pub ephemeral: bool,
pub show_context_menu_commands: bool,
pub show_subcommands: bool,
pub include_description: bool,
/* private fields */
}Expand description
Optional configuration for how the help message from help() looks
Fields
extra_text_at_bottom: &'a strExtra text displayed at the bottom of your message. Can be used for help and tips specific to your bot
ephemeral: boolWhether to make the response ephemeral if possible. Can be nice to reduce clutter
Whether to list context menu commands as well
show_subcommands: boolWhether to list context menu commands as well
include_description: boolWhether to include crate::Command::description (above crate::Command::help_text).